# cerillo

Cerillo python API for control of Cerillo devices

[![PyPI - Version](https://img.shields.io/pypi/v/cerillo-python.svg)](https://pypi.org/project/cerillo-python)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cerillo-python.svg)](https://pypi.org/project/cerillo-python)

-----

## Table of Contents

- [cerillo](#cerillo)
  - [Table of Contents](#table-of-contents)
  - [Installation](#installation)
  - [License](#license)

## Installation

```console
pip install cerillo
```

## License

`cerillo` is distributed under the terms of the [GPLv3](https://spdx.org/licenses/GPL-3.0-or-later.html) license.
